@@ -11,7 +11,6 @@ from matplotlib.transforms import Bbox
 from matplotlib.offsetbox import AnchoredText
 from mpl_toolkits.axes_grid1 import make_axes_locatable, axes_size
 
-from .error_estimation import poisson_interval
 from .utils import (
     get_histogram_axes_title,
     process_histogram_parts,
@@ -22,18 +21,12 @@ from .utils import (
 if TYPE_CHECKING:
     from numpy.typing import ArrayLike
 
-# mpl updated to new methods
-# from packaging import version
-# _mpl_up_version = "3.3.3"
-# _mpl_up = version.parse(mpl.__version__) >= version.parse(_mpl_up_version)
-
-StepArtists = namedtuple("StepArtists", "step errorbar legend_artist")
-FillArtists = namedtuple("FillArtists", "fill_between")
+StairsArtists = namedtuple("StairsArtists", "stairs errorbar legend_artist")
 ErrorBarArtists = namedtuple("ErrorBarArtists", "errorbar")
 ColormeshArtists = namedtuple("ColormeshArtists", "pcolormesh cbar")
 
 
-Hist1DArtists = Union[StepArtists, FillArtists, ErrorBarArtists]
+Hist1DArtists = Union[StairsArtists, ErrorBarArtists]
 Hist2DArtists = ColormeshArtists
 
 
@@ -61,6 +54,19 @@ def get_stack(_h, hists):
         return _h
 
 
+def soft_update_kwargs(kwargs, mods, rc=True):
+    not_default = [k for k, v in mpl.rcParamsDefault.items() if v != mpl.rcParams[k]]
+    aliases = {"ls": "linestyle"}
+    kwargs = {aliases[k] if k in aliases else k: v for k, v in kwargs.items()}
+    for key, val in mods.items():
+        rc_modded = (key in not_default) or (
+            key in [k.split(".")[-1] for k in not_default]
+        )
+        if key not in kwargs and (rc and not rc_modded):
+            kwargs[key] = val
+    return kwargs
+
+
 ########################################
 # Histogram plotter
 def histplot(
@@ -74,6 +80,7 @@ def histplot(
     density=False,
     binwnorm=None,
     histtype="step",
+    xerr=False,
     label=None,
     edges=True,
     binticks=False,
@@ -119,7 +126,8 @@ def histplot(
             - "step": skyline/step/outline of a histogram using `plt.step <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.axes.Axes.step.html#matplotlib.axes.Axes.step>`_
             - "fill": filled histogram using `plt.fill_between <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.axes.Axes.step.html#matplotlib.axes.Axes.step>`_
             - "errorbar": single marker histogram using `plt.errorbar <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.axes.Axes.step.html#matplotlib.axes.Axes.step>`_
-
+        xerr:  bool or float, optional
+            Size of xerr if ``histtype == 'errorbar'``. If ``True``, bin-width will be used.
         label : str or list, optional
             Label for legend entry.
         edges : bool, default: True, optional
@@ -231,7 +239,17 @@ def histplot(
             int_w2 = np.around(w2).astype(int)
             if np.all(np.isclose(w2, int_w2, 0.000001)):
                 # If w2 are integers (true data hist), calculate Garwood interval
-                _yerr = np.abs(poisson_interval(h[0], w2) - h[0])
+                try:
+                    from .error_estimation import poisson_interval
+
+                    _yerr = np.abs(poisson_interval(h[0], w2) - h[0])
+                except ImportError:
+                    warnings.warn(
+                        "Integer weights indicate poissonian data. Will calculate "
+                        "Garwood interval if ``scipy`` is installed. Otherwise errors "
+                        "will be set to ``sqrt(w2)``."
+                    )
+                    _yerr = np.sqrt(w2)
             else:
                 # w2 to errors directly if specified previously
                 _yerr = np.sqrt(w2)
@@ -272,7 +290,6 @@ def histplot(
 
     ############################
     # Stacking, norming, density
-
     if density or binwnorm is not None:
         density_arr = get_density(h, density, binwnorm, bins=final_bins, hists=hists)
         if stack:
@@ -300,51 +317,49 @@ def histplot(
 
     ##########
     # Plotting
-    return_artists: List[Union[FillArtists, StepArtists, ErrorBarArtists]] = []
+    return_artists: List[Union[StairsArtists, ErrorBarArtists]] = []
     if histtype == "step":
         for i in range(len(hists)):
-            if edges:
-                _bins = [final_bins[0], *final_bins, final_bins[-1]]
-                _h = [0, *h[i], h[i][-1], 0]
-            else:
-                _bins = list(final_bins)
-                _h = [*h[i], h[i][-1]]
             _kwargs = _chunked_kwargs[i]
             _label = _labels[i]
             _step_label = _label if yerr is None else None
-            (_s,) = ax.step(
-                _bins, _h, where="post", label=_step_label, marker="", **_kwargs
+            _kwargs = soft_update_kwargs(_kwargs, {"linewidth": 1.5})
+
+            _s = ax.stairs(
+                h[i],
+                final_bins,
+                baseline=None if not edges else 0,
+                label=_step_label,
+                **_kwargs,
             )
+
             if yerr is not None or w2 is not None:
-                if "color" not in _kwargs:
-                    _kwargs["color"] = _s.get_color()
-                _kwargs["linestyle"] = "none"
+                _kwargs = soft_update_kwargs(
+                    _kwargs, {"color": _s.get_edgecolor(), "linestyle": "none"}
+                )
                 _e = ax.errorbar(
                     _bin_centers,
                     h[i],
                     yerr=[_yerr_lo[i], _yerr_hi[i]],
                     **_kwargs,
                 )
-                _eleg = ax.errorbar(
-                    [], [], yerr=1, xerr=1, color=_s.get_color(), label=_label
+                _e_leg = ax.errorbar(
+                    [], [], yerr=1, xerr=1, color=_s.get_edgecolor(), label=_label
                 )
             return_artists.append(
-                StepArtists(
+                StairsArtists(
                     _s,
                     _e if yerr is not None or w2 is not None else None,
-                    _eleg if yerr is not None or w2 is not None else None,
+                    _e_leg if yerr is not None or w2 is not None else None,
                 )
             )
         _artist = _s
 
     elif histtype == "fill":
         for i in range(len(hists)):
-            _h = np.r_[h[i], h[i][-1]]
             _kwargs = _chunked_kwargs[i]
-            _f = ax.fill_between(
-                final_bins, _h, step="post", label=_labels[i], **_kwargs
-            )
-        return_artists.append(FillArtists(_f))
+            _f = ax.stairs(h[i], final_bins, label=_labels[i], fill=True, **_kwargs)
+        return_artists.append(StairsArtists(_f, None, None))
         _artist = _f
 
     elif histtype == "errorbar":
@@ -355,12 +370,10 @@ def histplot(
             "elinewidth": 1,
         }
         _yerri: Optional[List[float]]
-        for k, v in err_defaults.items():
-            if k not in kwargs.keys():
-                kwargs[k] = v
-            for kwarg_row in _chunked_kwargs:
-                if k not in kwarg_row.keys():
-                    kwarg_row[k] = v
+        if xerr is True:
+            _xerr = _bin_widths / 2
+        elif isinstance(xerr, (int, float)):
+            _xerr = xerr
 
         for i in range(len(hists)):
             if yerr is not None or w2 is not None:
@@ -368,7 +381,12 @@ def histplot(
             else:
                 _yerri = None
             _e = ax.errorbar(
-                _bin_centers, h[i], yerr=_yerri, label=_labels[i], **_chunked_kwargs[i]
+                _bin_centers,
+                h[i],
+                yerr=_yerri,
+                xerr=_xerr if xerr else None,
+                label=_labels[i],
+                **soft_update_kwargs(_chunked_kwargs[i], err_defaults),
             )
             return_artists.append(ErrorBarArtists(_e))
 
@@ -509,9 +527,7 @@ def hist2dplot(
             _labels = H
         elif H.shape == labels.shape:
             _labels = labels
-        elif labels is False:
-            pass
-        else:
+        elif labels is not False:
             raise ValueError(
                 "Labels not understood, either specify a bool or a" "Histlike array "
             )
@@ -577,9 +593,7 @@ def _draw_leg_bbox(ax):
     leg = ax.get_legend()
 
     fig.canvas.draw()
-    bbox = leg.get_frame().get_bbox()
-
-    return bbox
+    return leg.get_frame().get_bbox()
 
 
 def _draw_text_bbox(ax):
@@ -587,11 +601,7 @@ def _draw_text_bbox(ax):
     Draw legend() and fetch it's bbox
     """
     fig = ax.figure
-    textboxes = []
-    for k in ax.get_children():
-        if type(k) == AnchoredText:
-            textboxes.append(k)
-
+    textboxes = [k for k in ax.get_children() if type(k) == AnchoredText]
     if len(textboxes) > 1:
         print("Warning: More than one textbox found")
         for box in textboxes:
@@ -610,11 +620,7 @@ def yscale_legend(ax=None):
     if ax is None:
         ax = plt.gca()
 
-    if ax.get_yscale() == "log":
-        scale_factor = 10 ** (1.05)
-    else:
-        scale_factor = 1.05
-
+    scale_factor = 10 ** (1.05) if ax.get_yscale() == "log" else 1.05
     while overlap(ax, _draw_leg_bbox(ax)) > 0:
         ax.set_ylim(ax.get_ylim()[0], ax.get_ylim()[-1] * scale_factor)
         ax.figure.canvas.draw()
@@ -764,12 +770,11 @@ def append_axes(ax, size=0.1, pad=0.1, position="right", extend=False):
     width, height = bbox.width, bbox.height
 
     def convert(fraction, position=position):
-        if isinstance(fraction, str):
-            if fraction.endswith("%"):
-                if position in ["right", "left"]:
-                    fraction = width * float(fraction.strip("%")) / 100
-                elif position in ["top", "bottom"]:
-                    fraction = height * float(fraction.strip("%")) / 100
+        if isinstance(fraction, str) and fraction.endswith("%"):
+            if position in ["right", "left"]:
+                fraction = width * float(fraction.strip("%")) / 100
+            elif position in ["top", "bottom"]:
+                fraction = height * float(fraction.strip("%")) / 100
         return fraction
 
     size = convert(size)
@@ -788,10 +793,7 @@ def append_axes(ax, size=0.1, pad=0.1, position="right", extend=False):
         def extend_ratio(ax, yhax):
             ax.figure.canvas.draw()
             orig_size = ax.get_position().size
-            new_size = 0
-            for itax in [ax, yhax]:
-                new_size += itax.get_position().size
-
+            new_size = sum(itax.get_position().size for itax in [ax, yhax])
             return new_size / orig_size
 
         if position in ["right"]:
@@ -900,10 +902,7 @@ def save_variations(fig, name, text_list=None, exp=None):
                 if exp is not None:
                     exp_label.set_text(exp)
                 suffix_text.set_text(text)
-        if text == "":
-            name_ext = ""
-        else:
-            name_ext = "_" + text.lower()
+        name_ext = "" if text == "" else "_" + text.lower()
         if exp is not None:
             name_ext = exp.lower() + name_ext
         save_name = name.split(".")[0] + name_ext + "." + name.split(".")[1]
